@@ -1,16 +1,13 @@
-from django import forms
 from django.contrib import admin
 from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
 
 from mptt.admin import MPTTModelAdmin
-from mptt.forms import TreeNodeChoiceField
 
 from fiber.editor import get_editor_field_name
-
 from app_settings import TEMPLATE_CHOICES
 from models import Page, ContentItem, PageContentItem, Image, File
-from utils.urls import get_named_url_from_quoted_url, is_quoted_url
+import admin_forms as forms
 
 
 class FiberAdminSite(admin.AdminSite):
@@ -19,30 +16,13 @@ class FiberAdminSite(admin.AdminSite):
 fiber_admin_site = FiberAdminSite(name='fiber_admin')
 
 
-class PageForm(forms.ModelForm):
-
-    parent = TreeNodeChoiceField(queryset=Page.tree.all(), level_indicator=3*unichr(160), empty_label='---------', required=False)
-    url = forms.RegexField(label=_('URL'), required=False, max_length=100, regex=r'^[-\w/\.\:"]+$',
-        help_text = _("""Example: '/section-1/products' or 'products' or '"some_named_url"'"""),
-        error_message = _('This value must contain only letters, numbers, underscores, dashes or slashes.'))
-    redirect_page = TreeNodeChoiceField(label=_('Redirect page'), queryset=Page.objects.filter(redirect_page__isnull=True), level_indicator=3*unichr(160), empty_label='---------', required=False)
-
-    class Meta:
-        model = Page
-
-    def clean_url(self):
-        if is_quoted_url(self.cleaned_data['url']) and not get_named_url_from_quoted_url(self.cleaned_data['url']):
-            raise forms.ValidationError(_('No reverse match found for the named url'))
-        return self.cleaned_data['url']
-
-    def clean_redirect_page(self):
-        if self.cleaned_data['redirect_page']:
-            try:
-                if self.cleaned_data['url'] and is_quoted_url(self.cleaned_data['url']):
-                    raise forms.ValidationError(_('A named url can\'t be combined with a redirect page'))
-            except KeyError:
-                pass
-        return self.cleaned_data['redirect_page']
+class ContentItemAdmin(admin.ModelAdmin):
+    list_display = ('__unicode__',)
+    form = forms.ContentItemAdminForm
+    fieldsets = (
+        (None, {'fields': ('name', get_editor_field_name('content_html'))}),
+        (_('Advanced options'), {'classes': ('collapse',), 'fields': ('protected', 'metadata',)}),
+    )
 
 
 class PageContentItemInline(admin.TabularInline):
@@ -52,7 +32,7 @@ class PageContentItemInline(admin.TabularInline):
 
 class PageAdmin(MPTTModelAdmin):
 
-    form = PageForm
+    form = forms.PageForm
     fieldsets = (
         (None, {'fields': ('parent', 'title', 'url', 'redirect_page', 'template_name')}),
         (_('Advanced options'), {'classes': ('collapse',), 'fields': ('mark_current_regexes', 'show_in_menu', 'protected', 'metadata',)}),
@@ -62,7 +42,7 @@ class PageAdmin(MPTTModelAdmin):
     list_display = ('title', 'view_on_site', 'url', 'redirect_page','get_absolute_url', 'action_links',)
     list_per_page = 1000
     search_fields = ('title', 'url', 'redirect_page')
-    
+
     def view_on_site(self, page):
         view_on_site = ''
 
@@ -100,16 +80,17 @@ class PageAdmin(MPTTModelAdmin):
     action_links.allow_tags = True
 
 
-admin.site.register(Page, PageAdmin)
-
-
-class FiberAdminPageForm(PageForm):
-    template_name = forms.ChoiceField(choices=TEMPLATE_CHOICES, required=False, label=_('Template'))
+class FiberAdminContentItemAdmin(admin.ModelAdmin):
+    list_display = ('__unicode__',)
+    form = forms.ContentItemAdminForm
+    fieldsets = (
+        (None, {'classes': ('hide-label',), 'fields': (get_editor_field_name('content_html'),)}),
+    )
 
 
 class FiberAdminPageAdmin(MPTTModelAdmin):
 
-    form = FiberAdminPageForm
+    form = forms.FiberAdminPageForm
 
     def __init__(self, *args, **kwargs):
         super(FiberAdminPageAdmin, self).__init__(*args, **kwargs)
@@ -137,36 +118,10 @@ class FiberAdminPageAdmin(MPTTModelAdmin):
         super(FiberAdminPageAdmin, self).save_model(request, obj, form, change)
 
 
-fiber_admin_site.register(Page, FiberAdminPageAdmin)
-
-
-class ContentItemAdminForm(forms.ModelForm):
-
-    class Meta:
-        model = ContentItem
-
-
-class ContentItemAdmin(admin.ModelAdmin):
-    list_display = ('__unicode__',)
-    form = ContentItemAdminForm
-    fieldsets = (
-        (None, {'fields': ('name', get_editor_field_name('content_html'))}),
-        (_('Advanced options'), {'classes': ('collapse',), 'fields': ('protected', 'metadata',)}),
-    )
-
 admin.site.register(ContentItem, ContentItemAdmin)
-
-
-class FiberAdminContentItemAdmin(admin.ModelAdmin):
-    list_display = ('__unicode__',)
-    form = ContentItemAdminForm
-    fieldsets = (
-        (None, {'classes': ('hide-label',), 'fields': (get_editor_field_name('content_html'),)}),
-    )
-fiber_admin_site.register(ContentItem, FiberAdminContentItemAdmin)
-
-
 admin.site.register(Image)
-
-
 admin.site.register(File)
+admin.site.register(Page, PageAdmin)
+
+fiber_admin_site.register(ContentItem, FiberAdminContentItemAdmin)
+fiber_admin_site.register(Page, FiberAdminPageAdmin)
